@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2015 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -22,7 +22,6 @@
 import sys
 from datetime import datetime
 
-from glances.compat import NoOptionError, NoSectionError
 from glances.logger import logger
 from glances.exports.glances_export import GlancesExport
 
@@ -37,36 +36,22 @@ class Export(GlancesExport):
         """Init the ES export IF."""
         super(Export, self).__init__(config=config, args=args)
 
-        # Load the ES configuration file
-        self.host = None
-        self.port = None
+        # Mandatories configuration keys (additional to host and port)
         self.index = None
-        self.export_enable = self.load_conf()
+
+        # Optionals configuration keys
+        # N/A
+
+        # Load the ES configuration file
+        self.export_enable = self.load_conf('elasticsearch',
+                                            mandatories=['host', 'port', 'index'],
+                                            options=[])
         if not self.export_enable:
             sys.exit(2)
 
         # Init the ES client
         self.client = self.init()
 
-    def load_conf(self, section="elasticsearch"):
-        """Load the ES configuration in the Glances configuration file."""
-        if self.config is None:
-            return False
-        try:
-            self.host = self.config.get_value(section, 'host')
-            self.port = self.config.get_value(section, 'port')
-            self.index = self.config.get_value(section, 'index')
-        except NoSectionError:
-            logger.critical("No ElasticSearch configuration found")
-            return False
-        except NoOptionError as e:
-            logger.critical("Error in the ElasticSearch configuration (%s)" % e)
-            return False
-        else:
-            logger.debug("Load ElasticSearch from the Glances configuration file")
-
-        return True
-
     def init(self):
         """Init the connection to the ES server."""
         if not self.export_enable:
